     /* Reverse polish notation calculator.  */
/*%locations*/
%defines
     %{
#include <math.h>
#include<stdlib.h>

#define YYSTYPE double
#define YYDEBUG 1
     %}

     %token NUM

     %% /* Grammar rules and actions follow.  */

     input:    /* empty */
             | input line
     ;
     
     line:     '\n'
             | exp '\n'      { fprintf (stderr,"\nResult%d: \t%.10g", 
					uv->instance,$1);  
}
     ;
     
     exp:      NUM           { $$ = $1;           }
             | exp exp '+'   { $$ = $1 + $2;      }
             | exp exp '-'   { $$ = $1 - $2;      }
             | exp exp '*'   { $$ = $1 * $2;      }
             | exp exp '/'   { $$ = $1 / $2;      }
              /* Exponentiation */
             | exp exp '^'   { $$ = pow ($1, $2); }
              /* Unary minus    */
             | exp 'n'       { $$ = -$1;          }
| 'x' {YYACCEPT}
     ;
     %%
/* The lexical analyzer returns a double floating point
   number on the stack and the token NUM, or the numeric code
   of the character read if not a number.  It skips all blanks
   and tabs, and returns 0 for end-of-input.  */
     
#include <ctype.h>

void
yyerror(const char *str) 
{
} 

void
yylex (struct yyuvars *u, FILE*fp)
{
	int c;
	
	/* Skip white space.  */
	while ((c = fgetc (fp)) == ' ' || c == '\t');
	/* Process numbers.  */
	if (c == '.' || isdigit (c))
	{
		ungetc (c, fp);
		fscanf (fp,"%lf", &u->yylval);
		u->token= NUM;
		return;
	}
	/* Return end-of-input.  */
	if (c == EOF){
		u->token= 0;
		return;
	}
	/* Return a single char.  */
	if(c=='\n') {
	}

	u->token= c;
	return;
}

int
main (void)
{
	void *pv[2];
	struct yyuvars *uv[2];
	FILE *fp[2];
	int i;
	//yydebug=1;
	for(i=0; i<2; i++) {
		fp[i]= fopen(i==0?"1.dat":"2.dat", "r");
		pv[i]= yypvarsinit();
		uv[i]= yyuvarsinit();
	}
	do {
		for(i=0; i<2; i++) {
			if(uv[i]->yyresult != 0) {
				yyparse(pv[i], uv[i]);
				
			}
			if(uv[i]->yyresult == 1) {
				fprintf(stderr,"\nSyntax error %d",
					uv[i]->instance);
			}
		}
		for(i=0; i<2; i++) {
			if(uv[i]->yyresult != 0) {
				yylex(uv[i], fp[i]);
			}
		}
	} while (uv[0]->yyresult!=0 || uv[1]->yyresult!=0);
	for(i=0; i<2; i++) {
		free(pv[i]);
		free(uv[i]);
		fclose(fp[i]);
	}
	fprintf(stderr, "\n");
	return 0;
}


