
#define YYSTYPE double
#include <ctype.h>
#include <stdio.h>
#include <stdlib.h>
#include "rpc.tab.h"
#include "ifx.tab.h"

#define GETNEXTTOKEN 4

struct yyuvars { /* In this case the same as zzuvars */
	int instance;
	int yyresult;
	int token;
	YYSTYPE yylval;
        //YYLTYPE yylloc; /* we haven't declared %locations */
};

void lexer (struct yyuvars *, FILE*);
void* yypvarsinit(void);
void* zzpvarsinit(void);
struct yyuvars* zzuvarsinit(void);
struct yyuvars* yyuvarsinit(void);
void zzparse (void *pvvoid, struct yyuvars *uv);
void yyparse (void *pvvoid, struct yyuvars *uv);
extern int zzdebug; /* we don't want debug for the yy-parser */

void 
yyerror(const char *str) 
{
	fprintf(stderr,"\nyyError: %s", str); 
} 
void 
zzerror(const char *str) 
{
	fprintf(stderr,"\nzzError: %s", str); 
} 

void
lexer (struct yyuvars *u, FILE*fp)
{
	int c;
     
	/* Skip white space.  */
	while ((c = fgetc (fp)) == ' ' || c == '\t')
		;
	/* Process numbers.  */
	if (c == '.' || isdigit (c))
	{
		ungetc (c, fp);
		fscanf (fp,"%lf", &u->yylval);
		u->token= NUM;
		return;
	}
	/* Return end-of-input.  */
	if (c == EOF){
		u->token= 0;
		return;
	}
	/* Return a single char.  */
	u->token= c;
	return;
}

int
main (void)
{
	void *pv[2];
	struct yyuvars *uv[2];
	FILE *fp[2];
	int i;
	//zzdebug=1; /* we don't want debug info for zzparse today */
	fp[0]= fopen("1.dat", "r");
	fp[1]= fopen("2.dat", "r");
	pv[0]= yypvarsinit();
	uv[0]= yyuvarsinit();
	pv[1]= zzpvarsinit();
	uv[1]= zzuvarsinit();
	uv[1]->instance++;
	do {
		if(uv[0]->yyresult != 0) {
			yyparse(pv[0], uv[0]);
		}
		if(uv[1]->yyresult != 0) {
			zzparse(pv[1], uv[1]);
		}
		for(i=0; i<2; i++) {
			if(uv[i]->yyresult == 1) {
				fprintf(stderr,"\nSyntax error%d",
					uv[i]->instance);
			}
		}
		for(i=0; i<2; i++) {
			if(uv[i]->yyresult != 0) {/* we use the same lexer for
						     both grammars */
				lexer(uv[i], fp[i]);
			}
		}
	} while (uv[0]->yyresult!=0 || uv[1]->yyresult!=0);
	for(i=0; i<2; i++) {
		free(pv[i]);
		free(uv[i]);
		fclose(fp[i]);
	}
	fprintf(stderr, "\n");
	return 0;
}

